# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ur_dashboard_msgs/srv/get_loaded_program.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/jazzy/ur_dashboard_msgs/srv/get_loaded_program.proto\x12\x30make87_messages_ros2.jazzy.ur_dashboard_msgs.srv\"\x19\n\x17GetLoadedProgramRequest\"Q\n\x18GetLoadedProgramResponse\x12\x0e\n\x06\x61nswer\x18\x01 \x01(\t\x12\x14\n\x0cprogram_name\x18\x02 \x01(\t\x12\x0f\n\x07success\x18\x03 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ur_dashboard_msgs.srv.get_loaded_program_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETLOADEDPROGRAMREQUEST']._serialized_start=127
  _globals['_GETLOADEDPROGRAMREQUEST']._serialized_end=152
  _globals['_GETLOADEDPROGRAMRESPONSE']._serialized_start=154
  _globals['_GETLOADEDPROGRAMRESPONSE']._serialized_end=235
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/map_msgs/srv/get_point_map.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.sensor_msgs.msg import point_cloud2_pb2 as make87__messages__ros2_dot_jazzy_dot_sensor__msgs_dot_msg_dot_point__cloud2__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;make87_messages_ros2/jazzy/map_msgs/srv/get_point_map.proto\x12\'make87_messages_ros2.jazzy.map_msgs.srv\x1a=make87_messages_ros2/jazzy/sensor_msgs/msg/point_cloud2.proto\"\x14\n\x12GetPointMapRequest\"[\n\x13GetPointMapResponse\x12\x44\n\x03map\x18\x01 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.sensor_msgs.msg.PointCloud2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.map_msgs.srv.get_point_map_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETPOINTMAPREQUEST']._serialized_start=167
  _globals['_GETPOINTMAPREQUEST']._serialized_end=187
  _globals['_GETPOINTMAPRESPONSE']._serialized_start=189
  _globals['_GETPOINTMAPRESPONSE']._serialized_end=280
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class RegionOfInterest2D(_message.Message):
    __slots__ = ("id", "offset_x", "offset_y", "width", "height")
    ID_FIELD_NUMBER: _ClassVar[int]
    OFFSET_X_FIELD_NUMBER: _ClassVar[int]
    OFFSET_Y_FIELD_NUMBER: _ClassVar[int]
    WIDTH_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    id: str
    offset_x: int
    offset_y: int
    width: int
    height: int
    def __init__(self, id: _Optional[str] = ..., offset_x: _Optional[int] = ..., offset_y: _Optional[int] = ..., width: _Optional[int] = ..., height: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rc_reason_msgs/srv/delete_regions_of_interest2_d.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rc_common_msgs.msg import return_code_pb2 as make87__messages__ros2_dot_rolling_dot_rc__common__msgs_dot_msg_dot_return__code__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSmake87_messages_ros2/rolling/rc_reason_msgs/srv/delete_regions_of_interest2_d.proto\x12/make87_messages_ros2.rolling.rc_reason_msgs.srv\x1a\x41make87_messages_ros2/rolling/rc_common_msgs/msg/return_code.proto\"E\n DeleteRegionsOfInterest2DRequest\x12!\n\x19region_of_interest_2d_ids\x18\x01 \x03(\t\"u\n!DeleteRegionsOfInterest2DResponse\x12P\n\x0breturn_code\x18\x01 \x01(\x0b\x32;.make87_messages_ros2.rolling.rc_common_msgs.msg.ReturnCodeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rc_reason_msgs.srv.delete_regions_of_interest2_d_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DELETEREGIONSOFINTEREST2DREQUEST']._serialized_start=203
  _globals['_DELETEREGIONSOFINTEREST2DREQUEST']._serialized_end=272
  _globals['_DELETEREGIONSOFINTEREST2DRESPONSE']._serialized_start=274
  _globals['_DELETEREGIONSOFINTEREST2DRESPONSE']._serialized_end=391
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ur_msgs/srv/set_force_mode.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_stamped_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_pose__stamped__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import twist_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_twist__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import wrench_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_wrench__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<make87_messages_ros2/humble/ur_msgs/srv/set_force_mode.proto\x12\'make87_messages_ros2.humble.ur_msgs.srv\x1a!make87_messages/core/header.proto\x1a@make87_messages_ros2/humble/geometry_msgs/msg/pose_stamped.proto\x1a\x39make87_messages_ros2/humble/geometry_msgs/msg/twist.proto\x1a:make87_messages_ros2/humble/geometry_msgs/msg/wrench.proto\"\xa7\x04\n\x13SetForceModeRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12N\n\ntask_frame\x18\x02 \x01(\x0b\x32:.make87_messages_ros2.humble.geometry_msgs.msg.PoseStamped\x12\x1a\n\x12selection_vector_x\x18\x03 \x01(\x08\x12\x1a\n\x12selection_vector_y\x18\x04 \x01(\x08\x12\x1a\n\x12selection_vector_z\x18\x05 \x01(\x08\x12\x1b\n\x13selection_vector_rx\x18\x06 \x01(\x08\x12\x1b\n\x13selection_vector_ry\x18\x07 \x01(\x08\x12\x1b\n\x13selection_vector_rz\x18\x08 \x01(\x08\x12\x45\n\x06wrench\x18\t \x01(\x0b\x32\x35.make87_messages_ros2.humble.geometry_msgs.msg.Wrench\x12\x0c\n\x04type\x18\n \x01(\r\x12J\n\x0cspeed_limits\x18\x0b \x01(\x0b\x32\x34.make87_messages_ros2.humble.geometry_msgs.msg.Twist\x12\x18\n\x10\x64\x65viation_limits\x18\x0c \x03(\x02\x12\x16\n\x0e\x64\x61mping_factor\x18\r \x01(\x02\x12\x14\n\x0cgain_scaling\x18\x0e \x01(\x02\"U\n\x14SetForceModeResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07success\x18\x02 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ur_msgs.srv.set_force_mode_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SETFORCEMODEREQUEST']._serialized_start=326
  _globals['_SETFORCEMODEREQUEST']._serialized_end=877
  _globals['_SETFORCEMODERESPONSE']._serialized_start=879
  _globals['_SETFORCEMODERESPONSE']._serialized_end=964
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/control_toolbox/srv/set_pid_gains.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/rolling/control_toolbox/srv/set_pid_gains.proto\x12\x30make87_messages_ros2.rolling.control_toolbox.srv\"Z\n\x12SetPidGainsRequest\x12\t\n\x01p\x18\x01 \x01(\x01\x12\t\n\x01i\x18\x02 \x01(\x01\x12\t\n\x01\x64\x18\x03 \x01(\x01\x12\x0f\n\x07i_clamp\x18\x04 \x01(\x01\x12\x12\n\nantiwindup\x18\x05 \x01(\x08\"\x15\n\x13SetPidGainsResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.control_toolbox.srv.set_pid_gains_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SETPIDGAINSREQUEST']._serialized_start=122
  _globals['_SETPIDGAINSREQUEST']._serialized_end=212
  _globals['_SETPIDGAINSRESPONSE']._serialized_start=214
  _globals['_SETPIDGAINSRESPONSE']._serialized_end=235
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ParamInfo(_message.Message):
    __slots__ = ("name", "resolved_name", "description", "group", "type", "dynamic", "default_int", "default_float", "default_double", "default_string", "default_bool", "max_value", "min_value")
    NAME_FIELD_NUMBER: _ClassVar[int]
    RESOLVED_NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    GROUP_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    DYNAMIC_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_INT_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_FLOAT_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_DOUBLE_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_STRING_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_BOOL_FIELD_NUMBER: _ClassVar[int]
    MAX_VALUE_FIELD_NUMBER: _ClassVar[int]
    MIN_VALUE_FIELD_NUMBER: _ClassVar[int]
    name: str
    resolved_name: str
    description: str
    group: str
    type: int
    dynamic: bool
    default_int: int
    default_float: float
    default_double: float
    default_string: str
    default_bool: bool
    max_value: float
    min_value: float
    def __init__(self, name: _Optional[str] = ..., resolved_name: _Optional[str] = ..., description: _Optional[str] = ..., group: _Optional[str] = ..., type: _Optional[int] = ..., dynamic: bool = ..., default_int: _Optional[int] = ..., default_float: _Optional[float] = ..., default_double: _Optional[float] = ..., default_string: _Optional[str] = ..., default_bool: bool = ..., max_value: _Optional[float] = ..., min_value: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/mobileye_560_660_msgs/msg/obstacle_status.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLmake87_messages_ros2/rolling/mobileye_560_660_msgs/msg/obstacle_status.proto\x12\x36make87_messages_ros2.rolling.mobileye_560_660_msgs.msg\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xd4\x02\n\x0eObstacleStatus\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x15\n\rnum_obstacles\x18\x02 \x01(\r\x12\x11\n\ttimestamp\x18\x03 \x01(\r\x12\x1b\n\x13\x61pplication_version\x18\x04 \x01(\r\x12%\n\x1d\x61\x63tive_version_number_section\x18\x05 \x01(\r\x12\x1f\n\x17left_close_range_cut_in\x18\x06 \x01(\x08\x12 \n\x18right_close_range_cut_in\x18\x07 \x01(\x08\x12\x0f\n\x07stop_go\x18\x08 \x01(\r\x12\x18\n\x10protocol_version\x18\t \x01(\r\x12\x11\n\tclose_car\x18\n \x01(\x08\x12\x10\n\x08\x66\x61ilsafe\x18\x0b \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.mobileye_560_660_msgs.msg.obstacle_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_OBSTACLESTATUS']._serialized_start=193
  _globals['_OBSTACLESTATUS']._serialized_end=533
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_traffic_msgs/msg/negotiation_proposal.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rmf_traffic_msgs.msg import negotiation_key_pb2 as make87__messages__ros2_dot_jazzy_dot_rmf__traffic__msgs_dot_msg_dot_negotiation__key__pb2
from make87_messages_ros2.jazzy.rmf_traffic_msgs.msg import route_pb2 as make87__messages__ros2_dot_jazzy_dot_rmf__traffic__msgs_dot_msg_dot_route__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/jazzy/rmf_traffic_msgs/msg/negotiation_proposal.proto\x12/make87_messages_ros2.jazzy.rmf_traffic_msgs.msg\x1a\x45make87_messages_ros2/jazzy/rmf_traffic_msgs/msg/negotiation_key.proto\x1a;make87_messages_ros2/jazzy/rmf_traffic_msgs/msg/route.proto\"\x97\x02\n\x13NegotiationProposal\x12\x18\n\x10\x63onflict_version\x18\x01 \x01(\x04\x12\x18\n\x10proposal_version\x18\x02 \x01(\x04\x12\x17\n\x0f\x66or_participant\x18\x03 \x01(\x04\x12W\n\x0eto_accommodate\x18\x04 \x03(\x0b\x32?.make87_messages_ros2.jazzy.rmf_traffic_msgs.msg.NegotiationKey\x12\x0f\n\x07plan_id\x18\x05 \x01(\x04\x12I\n\titinerary\x18\x06 \x03(\x0b\x32\x36.make87_messages_ros2.jazzy.rmf_traffic_msgs.msg.Routeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_traffic_msgs.msg.negotiation_proposal_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_NEGOTIATIONPROPOSAL']._serialized_start=260
  _globals['_NEGOTIATIONPROPOSAL']._serialized_end=539
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/autoware_adapi_version_msgs/srv/interface_version.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nTmake87_messages_ros2/rolling/autoware_adapi_version_msgs/srv/interface_version.proto\x12<make87_messages_ros2.rolling.autoware_adapi_version_msgs.srv\"\x19\n\x17InterfaceVersionRequest\"G\n\x18InterfaceVersionResponse\x12\r\n\x05major\x18\x01 \x01(\r\x12\r\n\x05minor\x18\x02 \x01(\r\x12\r\n\x05patch\x18\x03 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.autoware_adapi_version_msgs.srv.interface_version_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_INTERFACEVERSIONREQUEST']._serialized_start=150
  _globals['_INTERFACEVERSIONREQUEST']._serialized_end=175
  _globals['_INTERFACEVERSIONRESPONSE']._serialized_start=177
  _globals['_INTERFACEVERSIONRESPONSE']._serialized_end=248
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NavSOL(_message.Message):
    __slots__ = ("header", "i_tow", "f_tow", "week", "gps_fix", "flags", "ecef_x", "ecef_y", "ecef_z", "p_acc", "ecef_vx", "ecef_vy", "ecef_vz", "s_acc", "p_dop", "reserved1", "num_sv", "reserved2")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    I_TOW_FIELD_NUMBER: _ClassVar[int]
    F_TOW_FIELD_NUMBER: _ClassVar[int]
    WEEK_FIELD_NUMBER: _ClassVar[int]
    GPS_FIX_FIELD_NUMBER: _ClassVar[int]
    FLAGS_FIELD_NUMBER: _ClassVar[int]
    ECEF_X_FIELD_NUMBER: _ClassVar[int]
    ECEF_Y_FIELD_NUMBER: _ClassVar[int]
    ECEF_Z_FIELD_NUMBER: _ClassVar[int]
    P_ACC_FIELD_NUMBER: _ClassVar[int]
    ECEF_VX_FIELD_NUMBER: _ClassVar[int]
    ECEF_VY_FIELD_NUMBER: _ClassVar[int]
    ECEF_VZ_FIELD_NUMBER: _ClassVar[int]
    S_ACC_FIELD_NUMBER: _ClassVar[int]
    P_DOP_FIELD_NUMBER: _ClassVar[int]
    RESERVED1_FIELD_NUMBER: _ClassVar[int]
    NUM_SV_FIELD_NUMBER: _ClassVar[int]
    RESERVED2_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    i_tow: int
    f_tow: int
    week: int
    gps_fix: int
    flags: int
    ecef_x: int
    ecef_y: int
    ecef_z: int
    p_acc: int
    ecef_vx: int
    ecef_vy: int
    ecef_vz: int
    s_acc: int
    p_dop: int
    reserved1: int
    num_sv: int
    reserved2: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., i_tow: _Optional[int] = ..., f_tow: _Optional[int] = ..., week: _Optional[int] = ..., gps_fix: _Optional[int] = ..., flags: _Optional[int] = ..., ecef_x: _Optional[int] = ..., ecef_y: _Optional[int] = ..., ecef_z: _Optional[int] = ..., p_acc: _Optional[int] = ..., ecef_vx: _Optional[int] = ..., ecef_vy: _Optional[int] = ..., ecef_vz: _Optional[int] = ..., s_acc: _Optional[int] = ..., p_dop: _Optional[int] = ..., reserved1: _Optional[int] = ..., num_sv: _Optional[int] = ..., reserved2: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/gps_msgs/msg/gps_fix.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.gps_msgs.msg import gps_status_pb2 as make87__messages__ros2_dot_jazzy_dot_gps__msgs_dot_msg_dot_gps__status__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5make87_messages_ros2/jazzy/gps_msgs/msg/gps_fix.proto\x12\'make87_messages_ros2.jazzy.gps_msgs.msg\x1a\x38make87_messages_ros2/jazzy/gps_msgs/msg/gps_status.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xe0\x04\n\x06GPSFix\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x42\n\x06status\x18\x02 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.gps_msgs.msg.GPSStatus\x12\x10\n\x08latitude\x18\x03 \x01(\x01\x12\x11\n\tlongitude\x18\x04 \x01(\x01\x12\x10\n\x08\x61ltitude\x18\x05 \x01(\x01\x12\r\n\x05track\x18\x06 \x01(\x01\x12\r\n\x05speed\x18\x07 \x01(\x01\x12\r\n\x05\x63limb\x18\x08 \x01(\x01\x12\r\n\x05pitch\x18\t \x01(\x01\x12\x0c\n\x04roll\x18\n \x01(\x01\x12\x0b\n\x03\x64ip\x18\x0b \x01(\x01\x12\x0c\n\x04time\x18\x0c \x01(\x01\x12\x0c\n\x04gdop\x18\r \x01(\x01\x12\x0c\n\x04pdop\x18\x0e \x01(\x01\x12\x0c\n\x04hdop\x18\x0f \x01(\x01\x12\x0c\n\x04vdop\x18\x10 \x01(\x01\x12\x0c\n\x04tdop\x18\x11 \x01(\x01\x12\x0b\n\x03\x65rr\x18\x12 \x01(\x01\x12\x10\n\x08\x65rr_horz\x18\x13 \x01(\x01\x12\x10\n\x08\x65rr_vert\x18\x14 \x01(\x01\x12\x11\n\terr_track\x18\x15 \x01(\x01\x12\x11\n\terr_speed\x18\x16 \x01(\x01\x12\x11\n\terr_climb\x18\x17 \x01(\x01\x12\x10\n\x08\x65rr_time\x18\x18 \x01(\x01\x12\x11\n\terr_pitch\x18\x19 \x01(\x01\x12\x10\n\x08\x65rr_roll\x18\x1a \x01(\x01\x12\x0f\n\x07\x65rr_dip\x18\x1b \x01(\x01\x12\x1b\n\x13position_covariance\x18\x1c \x03(\x01\x12 \n\x18position_covariance_type\x18\x1d \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.gps_msgs.msg.gps_fix_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GPSFIX']._serialized_start=211
  _globals['_GPSFIX']._serialized_end=819
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.rmf_task_msgs.msg import task_summary_pb2 as _task_summary_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Tasks(_message.Message):
    __slots__ = ("tasks",)
    TASKS_FIELD_NUMBER: _ClassVar[int]
    tasks: _containers.RepeatedCompositeFieldContainer[_task_summary_pb2.TaskSummary]
    def __init__(self, tasks: _Optional[_Iterable[_Union[_task_summary_pb2.TaskSummary, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as _time_pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from make87_messages_ros2.rolling.wiimote_msgs.msg import ir_source_info_pb2 as _ir_source_info_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class State(_message.Message):
    __slots__ = ("header", "angular_velocity_zeroed", "angular_velocity_raw", "angular_velocity_covariance", "linear_acceleration_zeroed", "linear_acceleration_raw", "linear_acceleration_covariance", "nunchuk_acceleration_zeroed", "nunchuk_acceleration_raw", "nunchuk_joystick_zeroed", "nunchuk_joystick_raw", "buttons", "nunchuk_buttons", "leds", "rumble", "ir_tracking", "raw_battery", "percent_battery", "zeroing_time", "errors")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ANGULAR_VELOCITY_ZEROED_FIELD_NUMBER: _ClassVar[int]
    ANGULAR_VELOCITY_RAW_FIELD_NUMBER: _ClassVar[int]
    ANGULAR_VELOCITY_COVARIANCE_FIELD_NUMBER: _ClassVar[int]
    LINEAR_ACCELERATION_ZEROED_FIELD_NUMBER: _ClassVar[int]
    LINEAR_ACCELERATION_RAW_FIELD_NUMBER: _ClassVar[int]
    LINEAR_ACCELERATION_COVARIANCE_FIELD_NUMBER: _ClassVar[int]
    NUNCHUK_ACCELERATION_ZEROED_FIELD_NUMBER: _ClassVar[int]
    NUNCHUK_ACCELERATION_RAW_FIELD_NUMBER: _ClassVar[int]
    NUNCHUK_JOYSTICK_ZEROED_FIELD_NUMBER: _ClassVar[int]
    NUNCHUK_JOYSTICK_RAW_FIELD_NUMBER: _ClassVar[int]
    BUTTONS_FIELD_NUMBER: _ClassVar[int]
    NUNCHUK_BUTTONS_FIELD_NUMBER: _ClassVar[int]
    LEDS_FIELD_NUMBER: _ClassVar[int]
    RUMBLE_FIELD_NUMBER: _ClassVar[int]
    IR_TRACKING_FIELD_NUMBER: _ClassVar[int]
    RAW_BATTERY_FIELD_NUMBER: _ClassVar[int]
    PERCENT_BATTERY_FIELD_NUMBER: _ClassVar[int]
    ZEROING_TIME_FIELD_NUMBER: _ClassVar[int]
    ERRORS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    angular_velocity_zeroed: _vector3_pb2.Vector3
    angular_velocity_raw: _vector3_pb2.Vector3
    angular_velocity_covariance: _containers.RepeatedScalarFieldContainer[float]
    linear_acceleration_zeroed: _vector3_pb2.Vector3
    linear_acceleration_raw: _vector3_pb2.Vector3
    linear_acceleration_covariance: _containers.RepeatedScalarFieldContainer[float]
    nunchuk_acceleration_zeroed: _vector3_pb2.Vector3
    nunchuk_acceleration_raw: _vector3_pb2.Vector3
    nunchuk_joystick_zeroed: _containers.RepeatedScalarFieldContainer[float]
    nunchuk_joystick_raw: _containers.RepeatedScalarFieldContainer[float]
    buttons: _containers.RepeatedScalarFieldContainer[bool]
    nunchuk_buttons: _containers.RepeatedScalarFieldContainer[bool]
    leds: _containers.RepeatedScalarFieldContainer[bool]
    rumble: bool
    ir_tracking: _containers.RepeatedCompositeFieldContainer[_ir_source_info_pb2.IrSourceInfo]
    raw_battery: float
    percent_battery: float
    zeroing_time: _time_pb2.Time
    errors: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., angular_velocity_zeroed: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., angular_velocity_raw: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., angular_velocity_covariance: _Optional[_Iterable[float]] = ..., linear_acceleration_zeroed: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., linear_acceleration_raw: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., linear_acceleration_covariance: _Optional[_Iterable[float]] = ..., nunchuk_acceleration_zeroed: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., nunchuk_acceleration_raw: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., nunchuk_joystick_zeroed: _Optional[_Iterable[float]] = ..., nunchuk_joystick_raw: _Optional[_Iterable[float]] = ..., buttons: _Optional[_Iterable[bool]] = ..., nunchuk_buttons: _Optional[_Iterable[bool]] = ..., leds: _Optional[_Iterable[bool]] = ..., rumble: bool = ..., ir_tracking: _Optional[_Iterable[_Union[_ir_source_info_pb2.IrSourceInfo, _Mapping]]] = ..., raw_battery: _Optional[float] = ..., percent_battery: _Optional[float] = ..., zeroing_time: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., errors: _Optional[int] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class RecStat(_message.Message):
    __slots__ = ("leap_sec", "clk_reset")
    LEAP_SEC_FIELD_NUMBER: _ClassVar[int]
    CLK_RESET_FIELD_NUMBER: _ClassVar[int]
    leap_sec: bool
    clk_reset: bool
    def __init__(self, leap_sec: bool = ..., clk_reset: bool = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Base2DKinematics(_message.Message):
    __slots__ = ("header", "min_vel_x", "max_vel_x", "min_vel_y", "max_vel_y", "max_vel_theta", "acc_lim_x", "decel_lim_x", "acc_lim_y", "decel_lim_y", "acc_lim_theta", "decel_lim_theta", "min_speed_xy", "max_speed_xy", "min_speed_theta")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    MIN_VEL_X_FIELD_NUMBER: _ClassVar[int]
    MAX_VEL_X_FIELD_NUMBER: _ClassVar[int]
    MIN_VEL_Y_FIELD_NUMBER: _ClassVar[int]
    MAX_VEL_Y_FIELD_NUMBER: _ClassVar[int]
    MAX_VEL_THETA_FIELD_NUMBER: _ClassVar[int]
    ACC_LIM_X_FIELD_NUMBER: _ClassVar[int]
    DECEL_LIM_X_FIELD_NUMBER: _ClassVar[int]
    ACC_LIM_Y_FIELD_NUMBER: _ClassVar[int]
    DECEL_LIM_Y_FIELD_NUMBER: _ClassVar[int]
    ACC_LIM_THETA_FIELD_NUMBER: _ClassVar[int]
    DECEL_LIM_THETA_FIELD_NUMBER: _ClassVar[int]
    MIN_SPEED_XY_FIELD_NUMBER: _ClassVar[int]
    MAX_SPEED_XY_FIELD_NUMBER: _ClassVar[int]
    MIN_SPEED_THETA_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    min_vel_x: float
    max_vel_x: float
    min_vel_y: float
    max_vel_y: float
    max_vel_theta: float
    acc_lim_x: float
    decel_lim_x: float
    acc_lim_y: float
    decel_lim_y: float
    acc_lim_theta: float
    decel_lim_theta: float
    min_speed_xy: float
    max_speed_xy: float
    min_speed_theta: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., min_vel_x: _Optional[float] = ..., max_vel_x: _Optional[float] = ..., min_vel_y: _Optional[float] = ..., max_vel_y: _Optional[float] = ..., max_vel_theta: _Optional[float] = ..., acc_lim_x: _Optional[float] = ..., decel_lim_x: _Optional[float] = ..., acc_lim_y: _Optional[float] = ..., decel_lim_y: _Optional[float] = ..., acc_lim_theta: _Optional[float] = ..., decel_lim_theta: _Optional[float] = ..., min_speed_xy: _Optional[float] = ..., max_speed_xy: _Optional[float] = ..., min_speed_theta: _Optional[float] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as _time_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ObjectB(_message.Message):
    __slots__ = ("header", "can_id", "stamp", "id", "time_since_meas", "zone", "rcs", "moving", "near", "exist_probability")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CAN_ID_FIELD_NUMBER: _ClassVar[int]
    STAMP_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    TIME_SINCE_MEAS_FIELD_NUMBER: _ClassVar[int]
    ZONE_FIELD_NUMBER: _ClassVar[int]
    RCS_FIELD_NUMBER: _ClassVar[int]
    MOVING_FIELD_NUMBER: _ClassVar[int]
    NEAR_FIELD_NUMBER: _ClassVar[int]
    EXIST_PROBABILITY_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    can_id: int
    stamp: _time_pb2.Time
    id: int
    time_since_meas: float
    zone: int
    rcs: float
    moving: bool
    near: bool
    exist_probability: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., can_id: _Optional[int] = ..., stamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., id: _Optional[int] = ..., time_since_meas: _Optional[float] = ..., zone: _Optional[int] = ..., rcs: _Optional[float] = ..., moving: bool = ..., near: bool = ..., exist_probability: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/septentrio_gnss_driver/msg/att_cov_euler.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.septentrio_gnss_driver.msg import block_header_pb2 as make87__messages__ros2_dot_jazzy_dot_septentrio__gnss__driver_dot_msg_dot_block__header__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/jazzy/septentrio_gnss_driver/msg/att_cov_euler.proto\x12\x35make87_messages_ros2.jazzy.septentrio_gnss_driver.msg\x1aHmake87_messages_ros2/jazzy/septentrio_gnss_driver/msg/block_header.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xbf\x02\n\x0b\x41ttCovEuler\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12X\n\x0c\x62lock_header\x18\x02 \x01(\x0b\x32\x42.make87_messages_ros2.jazzy.septentrio_gnss_driver.msg.BlockHeader\x12\r\n\x05\x65rror\x18\x03 \x01(\r\x12\x14\n\x0c\x63ov_headhead\x18\x04 \x01(\x02\x12\x16\n\x0e\x63ov_pitchpitch\x18\x05 \x01(\x02\x12\x14\n\x0c\x63ov_rollroll\x18\x06 \x01(\x02\x12\x15\n\rcov_headpitch\x18\x07 \x01(\x02\x12\x14\n\x0c\x63ov_headroll\x18\x08 \x01(\x02\x12\x15\n\rcov_pitchroll\x18\t \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.septentrio_gnss_driver.msg.att_cov_euler_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ATTCOVEULER']._serialized_start=261
  _globals['_ATTCOVEULER']._serialized_end=580
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MountControl(_message.Message):
    __slots__ = ("header", "mode", "pitch", "roll", "yaw", "altitude", "latitude", "longitude")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    PITCH_FIELD_NUMBER: _ClassVar[int]
    ROLL_FIELD_NUMBER: _ClassVar[int]
    YAW_FIELD_NUMBER: _ClassVar[int]
    ALTITUDE_FIELD_NUMBER: _ClassVar[int]
    LATITUDE_FIELD_NUMBER: _ClassVar[int]
    LONGITUDE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    mode: int
    pitch: float
    roll: float
    yaw: float
    altitude: float
    latitude: float
    longitude: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., mode: _Optional[int] = ..., pitch: _Optional[float] = ..., roll: _Optional[float] = ..., yaw: _Optional[float] = ..., altitude: _Optional[float] = ..., latitude: _Optional[float] = ..., longitude: _Optional[float] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RelativeObstacleInfo(_message.Message):
    __slots__ = ("header", "ros2_header", "down", "front", "right", "back", "left", "up", "down_health", "front_health", "right_health", "back_health", "left_health", "up_health", "reserved")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    DOWN_FIELD_NUMBER: _ClassVar[int]
    FRONT_FIELD_NUMBER: _ClassVar[int]
    RIGHT_FIELD_NUMBER: _ClassVar[int]
    BACK_FIELD_NUMBER: _ClassVar[int]
    LEFT_FIELD_NUMBER: _ClassVar[int]
    UP_FIELD_NUMBER: _ClassVar[int]
    DOWN_HEALTH_FIELD_NUMBER: _ClassVar[int]
    FRONT_HEALTH_FIELD_NUMBER: _ClassVar[int]
    RIGHT_HEALTH_FIELD_NUMBER: _ClassVar[int]
    BACK_HEALTH_FIELD_NUMBER: _ClassVar[int]
    LEFT_HEALTH_FIELD_NUMBER: _ClassVar[int]
    UP_HEALTH_FIELD_NUMBER: _ClassVar[int]
    RESERVED_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    down: float
    front: float
    right: float
    back: float
    left: float
    up: float
    down_health: int
    front_health: int
    right_health: int
    back_health: int
    left_health: int
    up_health: int
    reserved: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., down: _Optional[float] = ..., front: _Optional[float] = ..., right: _Optional[float] = ..., back: _Optional[float] = ..., left: _Optional[float] = ..., up: _Optional[float] = ..., down_health: _Optional[int] = ..., front_health: _Optional[int] = ..., right_health: _Optional[int] = ..., back_health: _Optional[int] = ..., left_health: _Optional[int] = ..., up_health: _Optional[int] = ..., reserved: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/diagnostic_msgs/srv/self_test.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.diagnostic_msgs.msg import diagnostic_status_pb2 as make87__messages__ros2_dot_jazzy_dot_diagnostic__msgs_dot_msg_dot_diagnostic__status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/jazzy/diagnostic_msgs/srv/self_test.proto\x12.make87_messages_ros2.jazzy.diagnostic_msgs.srv\x1a\x46make87_messages_ros2/jazzy/diagnostic_msgs/msg/diagnostic_status.proto\"\x11\n\x0fSelfTestRequest\"\x80\x01\n\x10SelfTestResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06passed\x18\x02 \x01(\r\x12P\n\x06status\x18\x03 \x03(\x0b\x32@.make87_messages_ros2.jazzy.diagnostic_msgs.msg.DiagnosticStatusb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.diagnostic_msgs.srv.self_test_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SELFTESTREQUEST']._serialized_start=186
  _globals['_SELFTESTREQUEST']._serialized_end=203
  _globals['_SELFTESTRESPONSE']._serialized_start=206
  _globals['_SELFTESTRESPONSE']._serialized_end=334
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SoftBiometrics(_message.Message):
    __slots__ = ("header", "ros2_header", "age", "age_confidence", "gender", "gender_confidence")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    AGE_FIELD_NUMBER: _ClassVar[int]
    AGE_CONFIDENCE_FIELD_NUMBER: _ClassVar[int]
    GENDER_FIELD_NUMBER: _ClassVar[int]
    GENDER_CONFIDENCE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    age: int
    age_confidence: float
    gender: int
    gender_confidence: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., age: _Optional[int] = ..., age_confidence: _Optional[float] = ..., gender: _Optional[int] = ..., gender_confidence: _Optional[float] = ...) -> None: ...



from make87_messages_ros2.jazzy.builtin_interfaces.msg import duration_pb2 as _duration_pb2
from make87_messages_ros2.jazzy.marine_sensor_msgs.msg import radar_echo_pb2 as _radar_echo_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RadarSector(_message.Message):
    __slots__ = ("header", "angle_start", "angle_increment", "time_increment", "scan_time", "range_min", "range_max", "intensities")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ANGLE_START_FIELD_NUMBER: _ClassVar[int]
    ANGLE_INCREMENT_FIELD_NUMBER: _ClassVar[int]
    TIME_INCREMENT_FIELD_NUMBER: _ClassVar[int]
    SCAN_TIME_FIELD_NUMBER: _ClassVar[int]
    RANGE_MIN_FIELD_NUMBER: _ClassVar[int]
    RANGE_MAX_FIELD_NUMBER: _ClassVar[int]
    INTENSITIES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    angle_start: float
    angle_increment: float
    time_increment: _duration_pb2.Duration
    scan_time: _duration_pb2.Duration
    range_min: float
    range_max: float
    intensities: _containers.RepeatedCompositeFieldContainer[_radar_echo_pb2.RadarEcho]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., angle_start: _Optional[float] = ..., angle_increment: _Optional[float] = ..., time_increment: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., scan_time: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., range_min: _Optional[float] = ..., range_max: _Optional[float] = ..., intensities: _Optional[_Iterable[_Union[_radar_echo_pb2.RadarEcho, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.jazzy.geometry_msgs.msg import point_pb2 as _point_pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import pose2_d_pb2 as _pose2_d_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class HandLandmark(_message.Message):
    __slots__ = ("label", "lm_score", "landmark", "position", "is_spatial")
    LABEL_FIELD_NUMBER: _ClassVar[int]
    LM_SCORE_FIELD_NUMBER: _ClassVar[int]
    LANDMARK_FIELD_NUMBER: _ClassVar[int]
    POSITION_FIELD_NUMBER: _ClassVar[int]
    IS_SPATIAL_FIELD_NUMBER: _ClassVar[int]
    label: str
    lm_score: float
    landmark: _containers.RepeatedCompositeFieldContainer[_pose2_d_pb2.Pose2D]
    position: _point_pb2.Point
    is_spatial: bool
    def __init__(self, label: _Optional[str] = ..., lm_score: _Optional[float] = ..., landmark: _Optional[_Iterable[_Union[_pose2_d_pb2.Pose2D, _Mapping]]] = ..., position: _Optional[_Union[_point_pb2.Point, _Mapping]] = ..., is_spatial: bool = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class RxmSVSISV(_message.Message):
    __slots__ = ("svid", "sv_flag", "azim", "elev", "age")
    SVID_FIELD_NUMBER: _ClassVar[int]
    SV_FLAG_FIELD_NUMBER: _ClassVar[int]
    AZIM_FIELD_NUMBER: _ClassVar[int]
    ELEV_FIELD_NUMBER: _ClassVar[int]
    AGE_FIELD_NUMBER: _ClassVar[int]
    svid: int
    sv_flag: int
    azim: int
    elev: int
    age: int
    def __init__(self, svid: _Optional[int] = ..., sv_flag: _Optional[int] = ..., azim: _Optional[int] = ..., elev: _Optional[int] = ..., age: _Optional[int] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class UICommand(_message.Message):
    __slots__ = ("command", "key")
    COMMAND_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    command: str
    key: str
    def __init__(self, command: _Optional[str] = ..., key: _Optional[str] = ...) -> None: ...



from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import schedule_identity_pb2 as _schedule_identity_pb2
from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import schedule_patch_pb2 as _schedule_patch_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MirrorUpdate(_message.Message):
    __slots__ = ("node_id", "database_version", "patch", "is_remedial_update")
    NODE_ID_FIELD_NUMBER: _ClassVar[int]
    DATABASE_VERSION_FIELD_NUMBER: _ClassVar[int]
    PATCH_FIELD_NUMBER: _ClassVar[int]
    IS_REMEDIAL_UPDATE_FIELD_NUMBER: _ClassVar[int]
    node_id: _schedule_identity_pb2.ScheduleIdentity
    database_version: int
    patch: _schedule_patch_pb2.SchedulePatch
    is_remedial_update: bool
    def __init__(self, node_id: _Optional[_Union[_schedule_identity_pb2.ScheduleIdentity, _Mapping]] = ..., database_version: _Optional[int] = ..., patch: _Optional[_Union[_schedule_patch_pb2.SchedulePatch, _Mapping]] = ..., is_remedial_update: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rosbridge_test_msgs/srv/test_multiple_response_fields.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nXmake87_messages_ros2/rolling/rosbridge_test_msgs/srv/test_multiple_response_fields.proto\x12\x34make87_messages_ros2.rolling.rosbridge_test_msgs.srv\"#\n!TestMultipleResponseFieldsRequest\"p\n\"TestMultipleResponseFieldsResponse\x12\x11\n\tint_value\x18\x01 \x01(\x05\x12\x13\n\x0b\x66loat_value\x18\x02 \x01(\x02\x12\x0e\n\x06string\x18\x03 \x01(\t\x12\x12\n\nbool_value\x18\x04 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rosbridge_test_msgs.srv.test_multiple_response_fields_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TESTMULTIPLERESPONSEFIELDSREQUEST']._serialized_start=146
  _globals['_TESTMULTIPLERESPONSEFIELDSREQUEST']._serialized_end=181
  _globals['_TESTMULTIPLERESPONSEFIELDSRESPONSE']._serialized_start=183
  _globals['_TESTMULTIPLERESPONSEFIELDSRESPONSE']._serialized_end=295
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rtabmap_msgs/msg/info.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import transform_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_transform__pb2
from make87_messages_ros2.humble.rtabmap_msgs.msg import map_graph_pb2 as make87__messages__ros2_dot_humble_dot_rtabmap__msgs_dot_msg_dot_map__graph__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7make87_messages_ros2/humble/rtabmap_msgs/msg/info.proto\x12,make87_messages_ros2.humble.rtabmap_msgs.msg\x1a!make87_messages/core/header.proto\x1a=make87_messages_ros2/humble/geometry_msgs/msg/transform.proto\x1a<make87_messages_ros2/humble/rtabmap_msgs/msg/map_graph.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xe4\x05\n\x04Info\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x0e\n\x06ref_id\x18\x03 \x01(\x05\x12\x17\n\x0floop_closure_id\x18\x04 \x01(\x05\x12\x1e\n\x16proximity_detection_id\x18\x05 \x01(\x05\x12\x13\n\x0blandmark_id\x18\x06 \x01(\x05\x12X\n\x16loop_closure_transform\x18\x07 \x01(\x0b\x32\x38.make87_messages_ros2.humble.geometry_msgs.msg.Transform\x12\x10\n\x08wm_state\x18\x08 \x03(\x05\x12\x16\n\x0eposterior_keys\x18\t \x03(\x05\x12\x18\n\x10posterior_values\x18\n \x03(\x02\x12\x17\n\x0flikelihood_keys\x18\x0b \x03(\x05\x12\x19\n\x11likelihood_values\x18\x0c \x03(\x02\x12\x1b\n\x13raw_likelihood_keys\x18\r \x03(\x05\x12\x1d\n\x15raw_likelihood_values\x18\x0e \x03(\x02\x12\x14\n\x0cweights_keys\x18\x0f \x03(\x05\x12\x16\n\x0eweights_values\x18\x10 \x03(\x05\x12\x13\n\x0blabels_keys\x18\x11 \x03(\x05\x12\x15\n\rlabels_values\x18\x12 \x03(\t\x12\x12\n\nstats_keys\x18\x13 \x03(\t\x12\x14\n\x0cstats_values\x18\x14 \x03(\x02\x12\x12\n\nlocal_path\x18\x15 \x03(\x05\x12\x17\n\x0f\x63urrent_goal_id\x18\x16 \x01(\x05\x12J\n\nodom_cache\x18\x17 \x01(\x0b\x32\x36.make87_messages_ros2.humble.rtabmap_msgs.msg.MapGraphb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rtabmap_msgs.msg.info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_INFO']._serialized_start=321
  _globals['_INFO']._serialized_end=1061
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.plansys2_msgs.msg import node_pb2 as _node_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ExistNodeRequest(_message.Message):
    __slots__ = ("node",)
    NODE_FIELD_NUMBER: _ClassVar[int]
    node: _node_pb2.Node
    def __init__(self, node: _Optional[_Union[_node_pb2.Node, _Mapping]] = ...) -> None: ...

class ExistNodeResponse(_message.Message):
    __slots__ = ("exist",)
    EXIST_FIELD_NUMBER: _ClassVar[int]
    exist: bool
    def __init__(self, exist: bool = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class PingInfo(_message.Message):
    __slots__ = ("frequency", "sound_speed", "tx_beamwidths", "rx_beamwidths")
    FREQUENCY_FIELD_NUMBER: _ClassVar[int]
    SOUND_SPEED_FIELD_NUMBER: _ClassVar[int]
    TX_BEAMWIDTHS_FIELD_NUMBER: _ClassVar[int]
    RX_BEAMWIDTHS_FIELD_NUMBER: _ClassVar[int]
    frequency: float
    sound_speed: float
    tx_beamwidths: _containers.RepeatedScalarFieldContainer[float]
    rx_beamwidths: _containers.RepeatedScalarFieldContainer[float]
    def __init__(self, frequency: _Optional[float] = ..., sound_speed: _Optional[float] = ..., tx_beamwidths: _Optional[_Iterable[float]] = ..., rx_beamwidths: _Optional[_Iterable[float]] = ...) -> None: ...



from make87_messages_ros2.jazzy.rmf_fleet_msgs.msg import speed_limited_lane_pb2 as _speed_limited_lane_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LaneStates(_message.Message):
    __slots__ = ("fleet_name", "closed_lanes", "speed_limits")
    FLEET_NAME_FIELD_NUMBER: _ClassVar[int]
    CLOSED_LANES_FIELD_NUMBER: _ClassVar[int]
    SPEED_LIMITS_FIELD_NUMBER: _ClassVar[int]
    fleet_name: str
    closed_lanes: _containers.RepeatedScalarFieldContainer[int]
    speed_limits: _containers.RepeatedCompositeFieldContainer[_speed_limited_lane_pb2.SpeedLimitedLane]
    def __init__(self, fleet_name: _Optional[str] = ..., closed_lanes: _Optional[_Iterable[int]] = ..., speed_limits: _Optional[_Iterable[_Union[_speed_limited_lane_pb2.SpeedLimitedLane, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.jazzy.rosapi_msgs.msg import type_def_pb2 as _type_def_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MessageDetailsRequest(_message.Message):
    __slots__ = ("type",)
    TYPE_FIELD_NUMBER: _ClassVar[int]
    type: str
    def __init__(self, type: _Optional[str] = ...) -> None: ...

class MessageDetailsResponse(_message.Message):
    __slots__ = ("typedefs",)
    TYPEDEFS_FIELD_NUMBER: _ClassVar[int]
    typedefs: _containers.RepeatedCompositeFieldContainer[_type_def_pb2.TypeDef]
    def __init__(self, typedefs: _Optional[_Iterable[_Union[_type_def_pb2.TypeDef, _Mapping]]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import wrench_pb2 as _wrench_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from make87_messages_ros2.humble.std_msgs.msg import string_pb2 as _string_pb2
from make87_messages_ros2.humble.std_msgs.msg import u_int32_pb2 as _u_int32_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class JointWrench(_message.Message):
    __slots__ = ("header", "ros2_header", "body_1_name", "body_1_id", "body_2_name", "body_2_id", "body_1_wrench", "body_2_wrench")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_1_NAME_FIELD_NUMBER: _ClassVar[int]
    BODY_1_ID_FIELD_NUMBER: _ClassVar[int]
    BODY_2_NAME_FIELD_NUMBER: _ClassVar[int]
    BODY_2_ID_FIELD_NUMBER: _ClassVar[int]
    BODY_1_WRENCH_FIELD_NUMBER: _ClassVar[int]
    BODY_2_WRENCH_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    body_1_name: _string_pb2.String
    body_1_id: _u_int32_pb2.UInt32
    body_2_name: _string_pb2.String
    body_2_id: _u_int32_pb2.UInt32
    body_1_wrench: _wrench_pb2.Wrench
    body_2_wrench: _wrench_pb2.Wrench
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., body_1_name: _Optional[_Union[_string_pb2.String, _Mapping]] = ..., body_1_id: _Optional[_Union[_u_int32_pb2.UInt32, _Mapping]] = ..., body_2_name: _Optional[_Union[_string_pb2.String, _Mapping]] = ..., body_2_id: _Optional[_Union[_u_int32_pb2.UInt32, _Mapping]] = ..., body_1_wrench: _Optional[_Union[_wrench_pb2.Wrench, _Mapping]] = ..., body_2_wrench: _Optional[_Union[_wrench_pb2.Wrench, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.rolling.geometry_msgs.msg import point_pb2 as _point_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Fiducial(_message.Message):
    __slots__ = ("ids", "ids_confidence", "object_points", "image_points")
    IDS_FIELD_NUMBER: _ClassVar[int]
    IDS_CONFIDENCE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_POINTS_FIELD_NUMBER: _ClassVar[int]
    IMAGE_POINTS_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[int]
    ids_confidence: _containers.RepeatedScalarFieldContainer[float]
    object_points: _containers.RepeatedCompositeFieldContainer[_point_pb2.Point]
    image_points: _containers.RepeatedCompositeFieldContainer[_point_pb2.Point]
    def __init__(self, ids: _Optional[_Iterable[int]] = ..., ids_confidence: _Optional[_Iterable[float]] = ..., object_points: _Optional[_Iterable[_Union[_point_pb2.Point, _Mapping]]] = ..., image_points: _Optional[_Iterable[_Union[_point_pb2.Point, _Mapping]]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NavSBASSV(_message.Message):
    __slots__ = ("header", "svid", "flags", "udre", "sv_sys", "sv_service", "reserved1", "prc", "reserved2", "ic")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SVID_FIELD_NUMBER: _ClassVar[int]
    FLAGS_FIELD_NUMBER: _ClassVar[int]
    UDRE_FIELD_NUMBER: _ClassVar[int]
    SV_SYS_FIELD_NUMBER: _ClassVar[int]
    SV_SERVICE_FIELD_NUMBER: _ClassVar[int]
    RESERVED1_FIELD_NUMBER: _ClassVar[int]
    PRC_FIELD_NUMBER: _ClassVar[int]
    RESERVED2_FIELD_NUMBER: _ClassVar[int]
    IC_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    svid: int
    flags: int
    udre: int
    sv_sys: int
    sv_service: int
    reserved1: int
    prc: int
    reserved2: int
    ic: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., svid: _Optional[int] = ..., flags: _Optional[int] = ..., udre: _Optional[int] = ..., sv_sys: _Optional[int] = ..., sv_service: _Optional[int] = ..., reserved1: _Optional[int] = ..., prc: _Optional[int] = ..., reserved2: _Optional[int] = ..., ic: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.jazzy.mavros_msgs.msg import esc_info_item_pb2 as _esc_info_item_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ESCInfo(_message.Message):
    __slots__ = ("header", "counter", "count", "connection_type", "info", "esc_info")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    COUNTER_FIELD_NUMBER: _ClassVar[int]
    COUNT_FIELD_NUMBER: _ClassVar[int]
    CONNECTION_TYPE_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    ESC_INFO_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    counter: int
    count: int
    connection_type: int
    info: int
    esc_info: _containers.RepeatedCompositeFieldContainer[_esc_info_item_pb2.ESCInfoItem]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., counter: _Optional[int] = ..., count: _Optional[int] = ..., connection_type: _Optional[int] = ..., info: _Optional[int] = ..., esc_info: _Optional[_Iterable[_Union[_esc_info_item_pb2.ESCInfoItem, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_door_msgs/msg/supervisor_heartbeat.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rmf_door_msgs.msg import door_sessions_pb2 as make87__messages__ros2_dot_jazzy_dot_rmf__door__msgs_dot_msg_dot_door__sessions__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/jazzy/rmf_door_msgs/msg/supervisor_heartbeat.proto\x12,make87_messages_ros2.jazzy.rmf_door_msgs.msg\x1a@make87_messages_ros2/jazzy/rmf_door_msgs/msg/door_sessions.proto\"g\n\x13SupervisorHeartbeat\x12P\n\x0c\x61ll_sessions\x18\x01 \x03(\x0b\x32:.make87_messages_ros2.jazzy.rmf_door_msgs.msg.DoorSessionsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_door_msgs.msg.supervisor_heartbeat_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SUPERVISORHEARTBEAT']._serialized_start=187
  _globals['_SUPERVISORHEARTBEAT']._serialized_end=290
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/off_highway_premium_radar_sample_msgs/msg/sensor_modulation_performance.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nimake87_messages_ros2/humble/off_highway_premium_radar_sample_msgs/msg/sensor_modulation_performance.proto\x12\x45make87_messages_ros2.humble.off_highway_premium_radar_sample_msgs.msg\x1a!make87_messages/core/header.proto\"\x90\x04\n\x1bSensorModulationPerformance\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12(\n detection_of_measurement_program\x18\x02 \x01(\r\x12\x15\n\rmodulation_id\x18\x03 \x01(\r\x12\x1e\n\x16\x64istance_range_scaling\x18\x04 \x01(\x02\x12\x1d\n\x15separability_distance\x18\x05 \x01(\x02\x12&\n\x1eseparability_relative_velocity\x18\x06 \x01(\x02\x12\x1a\n\x12precision_distance\x18\x07 \x01(\x02\x12#\n\x1bprecision_relative_velocity\x18\x08 \x01(\x02\x12\x34\n,covariance_of_distance_and_relative_velocity\x18\t \x01(\x02\x12#\n\x1bminimum_measurable_distance\x18\n \x01(\x02\x12#\n\x1bmaximum_measurable_distance\x18\x0b \x01(\x02\x12,\n$minimum_measurable_relative_velocity\x18\x0c \x01(\x02\x12,\n$maximum_measurable_relative_velocity\x18\r \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.off_highway_premium_radar_sample_msgs.msg.sensor_modulation_performance_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SENSORMODULATIONPERFORMANCE']._serialized_start=216
  _globals['_SENSORMODULATIONPERFORMANCE']._serialized_end=744
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/canopen_interfaces/srv/co_write.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/humble/canopen_interfaces/srv/co_write.proto\x12\x32make87_messages_ros2.humble.canopen_interfaces.srv\x1a!make87_messages/core/header.proto\"m\n\x0e\x43OWriteRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\r\n\x05index\x18\x02 \x01(\r\x12\x10\n\x08subindex\x18\x03 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\r\"P\n\x0f\x43OWriteResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07success\x18\x02 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.canopen_interfaces.srv.co_write_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_COWRITEREQUEST']._serialized_start=156
  _globals['_COWRITEREQUEST']._serialized_end=265
  _globals['_COWRITERESPONSE']._serialized_start=267
  _globals['_COWRITERESPONSE']._serialized_end=347
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.rclpy_message_converter_msgs.msg import uint8_array_test_message_pb2 as _uint8_array_test_message_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NestedUint8ArrayTestMessage(_message.Message):
    __slots__ = ("arrays",)
    ARRAYS_FIELD_NUMBER: _ClassVar[int]
    arrays: _containers.RepeatedCompositeFieldContainer[_uint8_array_test_message_pb2.Uint8ArrayTestMessage]
    def __init__(self, arrays: _Optional[_Iterable[_Union[_uint8_array_test_message_pb2.Uint8ArrayTestMessage, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/sick_safetyscanners2_interfaces/msg/extended_laser_scan.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.sensor_msgs.msg import laser_scan_pb2 as make87__messages__ros2_dot_jazzy_dot_sensor__msgs_dot_msg_dot_laser__scan__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nXmake87_messages_ros2/jazzy/sick_safetyscanners2_interfaces/msg/extended_laser_scan.proto\x12>make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg\x1a;make87_messages_ros2/jazzy/sensor_msgs/msg/laser_scan.proto\"\xa5\x01\n\x11\x45xtendedLaserScan\x12I\n\nlaser_scan\x18\x01 \x01(\x0b\x32\x35.make87_messages_ros2.jazzy.sensor_msgs.msg.LaserScan\x12\x18\n\x10reflektor_status\x18\x02 \x03(\x08\x12\x18\n\x10reflektor_median\x18\x03 \x03(\x08\x12\x11\n\tintrusion\x18\x04 \x03(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg.extended_laser_scan_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_EXTENDEDLASERSCAN']._serialized_start=218
  _globals['_EXTENDEDLASERSCAN']._serialized_end=383
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NavDGPSSV(_message.Message):
    __slots__ = ("header", "svid", "flags", "age_c", "prc", "prrc")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SVID_FIELD_NUMBER: _ClassVar[int]
    FLAGS_FIELD_NUMBER: _ClassVar[int]
    AGE_C_FIELD_NUMBER: _ClassVar[int]
    PRC_FIELD_NUMBER: _ClassVar[int]
    PRRC_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    svid: int
    flags: int
    age_c: int
    prc: float
    prrc: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., svid: _Optional[int] = ..., flags: _Optional[int] = ..., age_c: _Optional[int] = ..., prc: _Optional[float] = ..., prrc: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/sick_safetyscanners2_interfaces/msg/intrusion_data.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg import intrusion_datum_pb2 as make87__messages__ros2_dot_jazzy_dot_sick__safetyscanners2__interfaces_dot_msg_dot_intrusion__datum__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSmake87_messages_ros2/jazzy/sick_safetyscanners2_interfaces/msg/intrusion_data.proto\x12>make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg\x1aTmake87_messages_ros2/jazzy/sick_safetyscanners2_interfaces/msg/intrusion_datum.proto\"m\n\rIntrusionData\x12\\\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32N.make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg.IntrusionDatumb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg.intrusion_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_INTRUSIONDATA']._serialized_start=237
  _globals['_INTRUSIONDATA']._serialized_end=346
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class GpgsvSatellite(_message.Message):
    __slots__ = ("prn", "elevation", "azimuth", "snr")
    PRN_FIELD_NUMBER: _ClassVar[int]
    ELEVATION_FIELD_NUMBER: _ClassVar[int]
    AZIMUTH_FIELD_NUMBER: _ClassVar[int]
    SNR_FIELD_NUMBER: _ClassVar[int]
    prn: int
    elevation: int
    azimuth: int
    snr: int
    def __init__(self, prn: _Optional[int] = ..., elevation: _Optional[int] = ..., azimuth: _Optional[int] = ..., snr: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ros_ign_interfaces/msg/world_control.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_humble_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.humble.ros_gz_interfaces.msg import world_reset_pb2 as make87__messages__ros2_dot_humble_dot_ros__gz__interfaces_dot_msg_dot_world__reset__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/humble/ros_ign_interfaces/msg/world_control.proto\x12\x32make87_messages_ros2.humble.ros_ign_interfaces.msg\x1a!make87_messages/core/header.proto\x1a=make87_messages_ros2/humble/builtin_interfaces/msg/time.proto\x1a\x43make87_messages_ros2/humble/ros_gz_interfaces/msg/world_reset.proto\"\x9c\x02\n\x0cWorldControl\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\r\n\x05pause\x18\x02 \x01(\x08\x12\x0c\n\x04step\x18\x03 \x01(\x08\x12\x12\n\nmulti_step\x18\x04 \x01(\r\x12L\n\x05reset\x18\x05 \x01(\x0b\x32=.make87_messages_ros2.humble.ros_gz_interfaces.msg.WorldReset\x12\x0c\n\x04seed\x18\x06 \x01(\r\x12Q\n\x0frun_to_sim_time\x18\x07 \x01(\x0b\x32\x38.make87_messages_ros2.humble.builtin_interfaces.msg.Timeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ros_ign_interfaces.msg.world_control_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_WORLDCONTROL']._serialized_start=294
  _globals['_WORLDCONTROL']._serialized_end=578
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.autoware_map_msgs.msg import point_cloud_map_cell_meta_data_pb2 as _point_cloud_map_cell_meta_data_pb2
from make87_messages_ros2.jazzy.sensor_msgs.msg import point_cloud2_pb2 as _point_cloud2_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PointCloudMapCellWithID(_message.Message):
    __slots__ = ("cell_id", "pointcloud", "metadata")
    CELL_ID_FIELD_NUMBER: _ClassVar[int]
    POINTCLOUD_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    cell_id: str
    pointcloud: _point_cloud2_pb2.PointCloud2
    metadata: _point_cloud_map_cell_meta_data_pb2.PointCloudMapCellMetaData
    def __init__(self, cell_id: _Optional[str] = ..., pointcloud: _Optional[_Union[_point_cloud2_pb2.PointCloud2, _Mapping]] = ..., metadata: _Optional[_Union[_point_cloud_map_cell_meta_data_pb2.PointCloudMapCellMetaData, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.jazzy.septentrio_gnss_driver.msg import block_header_pb2 as _block_header_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class VelCovCartesian(_message.Message):
    __slots__ = ("header", "block_header", "mode", "error", "cov_vxvx", "cov_vyvy", "cov_vzvz", "cov_dtdt", "cov_vxvy", "cov_vxvz", "cov_vxdt", "cov_vyvz", "cov_vydt", "cov_vzdt")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BLOCK_HEADER_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    COV_VXVX_FIELD_NUMBER: _ClassVar[int]
    COV_VYVY_FIELD_NUMBER: _ClassVar[int]
    COV_VZVZ_FIELD_NUMBER: _ClassVar[int]
    COV_DTDT_FIELD_NUMBER: _ClassVar[int]
    COV_VXVY_FIELD_NUMBER: _ClassVar[int]
    COV_VXVZ_FIELD_NUMBER: _ClassVar[int]
    COV_VXDT_FIELD_NUMBER: _ClassVar[int]
    COV_VYVZ_FIELD_NUMBER: _ClassVar[int]
    COV_VYDT_FIELD_NUMBER: _ClassVar[int]
    COV_VZDT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    block_header: _block_header_pb2.BlockHeader
    mode: int
    error: int
    cov_vxvx: float
    cov_vyvy: float
    cov_vzvz: float
    cov_dtdt: float
    cov_vxvy: float
    cov_vxvz: float
    cov_vxdt: float
    cov_vyvz: float
    cov_vydt: float
    cov_vzdt: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., block_header: _Optional[_Union[_block_header_pb2.BlockHeader, _Mapping]] = ..., mode: _Optional[int] = ..., error: _Optional[int] = ..., cov_vxvx: _Optional[float] = ..., cov_vyvy: _Optional[float] = ..., cov_vzvz: _Optional[float] = ..., cov_dtdt: _Optional[float] = ..., cov_vxvy: _Optional[float] = ..., cov_vxvz: _Optional[float] = ..., cov_vxdt: _Optional[float] = ..., cov_vyvz: _Optional[float] = ..., cov_vydt: _Optional[float] = ..., cov_vzdt: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/mavros_msgs/msg/vehicle_info.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/jazzy/mavros_msgs/msg/vehicle_info.proto\x12*make87_messages_ros2.jazzy.mavros_msgs.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xd5\x03\n\x0bVehicleInfo\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x16\n\x0e\x61vailable_info\x18\x02 \x01(\r\x12\r\n\x05sysid\x18\x03 \x01(\r\x12\x0e\n\x06\x63ompid\x18\x04 \x01(\r\x12\x11\n\tautopilot\x18\x05 \x01(\r\x12\x0c\n\x04type\x18\x06 \x01(\r\x12\x15\n\rsystem_status\x18\x07 \x01(\r\x12\x11\n\tbase_mode\x18\x08 \x01(\r\x12\x13\n\x0b\x63ustom_mode\x18\t \x01(\r\x12\x0c\n\x04mode\x18\n \x01(\t\x12\x0f\n\x07mode_id\x18\x0b \x01(\r\x12\x14\n\x0c\x63\x61pabilities\x18\x0c \x01(\x04\x12\x19\n\x11\x66light_sw_version\x18\r \x01(\r\x12\x1d\n\x15middleware_sw_version\x18\x0e \x01(\r\x12\x15\n\ros_sw_version\x18\x0f \x01(\r\x12\x15\n\rboard_version\x18\x10 \x01(\r\x12\x1d\n\x15\x66light_custom_version\x18\x11 \x01(\t\x12\x11\n\tvendor_id\x18\x12 \x01(\r\x12\x12\n\nproduct_id\x18\x13 \x01(\r\x12\x0b\n\x03uid\x18\x14 \x01(\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.mavros_msgs.msg.vehicle_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_VEHICLEINFO']._serialized_start=164
  _globals['_VEHICLEINFO']._serialized_end=633
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.std_msgs.msg import float32_multi_array_pb2 as _float32_multi_array_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import int32_pb2 as _int32_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import string_pb2 as _string_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DetectionInfo(_message.Message):
    __slots__ = ("header", "ids", "widths", "heights", "file_paths", "inliers", "outliers", "homographies")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    IDS_FIELD_NUMBER: _ClassVar[int]
    WIDTHS_FIELD_NUMBER: _ClassVar[int]
    HEIGHTS_FIELD_NUMBER: _ClassVar[int]
    FILE_PATHS_FIELD_NUMBER: _ClassVar[int]
    INLIERS_FIELD_NUMBER: _ClassVar[int]
    OUTLIERS_FIELD_NUMBER: _ClassVar[int]
    HOMOGRAPHIES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ids: _containers.RepeatedCompositeFieldContainer[_int32_pb2.Int32]
    widths: _containers.RepeatedCompositeFieldContainer[_int32_pb2.Int32]
    heights: _containers.RepeatedCompositeFieldContainer[_int32_pb2.Int32]
    file_paths: _containers.RepeatedCompositeFieldContainer[_string_pb2.String]
    inliers: _containers.RepeatedCompositeFieldContainer[_int32_pb2.Int32]
    outliers: _containers.RepeatedCompositeFieldContainer[_int32_pb2.Int32]
    homographies: _containers.RepeatedCompositeFieldContainer[_float32_multi_array_pb2.Float32MultiArray]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ids: _Optional[_Iterable[_Union[_int32_pb2.Int32, _Mapping]]] = ..., widths: _Optional[_Iterable[_Union[_int32_pb2.Int32, _Mapping]]] = ..., heights: _Optional[_Iterable[_Union[_int32_pb2.Int32, _Mapping]]] = ..., file_paths: _Optional[_Iterable[_Union[_string_pb2.String, _Mapping]]] = ..., inliers: _Optional[_Iterable[_Union[_int32_pb2.Int32, _Mapping]]] = ..., outliers: _Optional[_Iterable[_Union[_int32_pb2.Int32, _Mapping]]] = ..., homographies: _Optional[_Iterable[_Union[_float32_multi_array_pb2.Float32MultiArray, _Mapping]]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.vimbax_camera_msgs.msg import feature_flags_pb2 as _feature_flags_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FeatureInfo(_message.Message):
    __slots__ = ("header", "name", "category", "display_name", "sfnc_namespace", "unit", "data_type", "flags", "polling_time")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CATEGORY_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    SFNC_NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    UNIT_FIELD_NUMBER: _ClassVar[int]
    DATA_TYPE_FIELD_NUMBER: _ClassVar[int]
    FLAGS_FIELD_NUMBER: _ClassVar[int]
    POLLING_TIME_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    name: str
    category: str
    display_name: str
    sfnc_namespace: str
    unit: str
    data_type: int
    flags: _feature_flags_pb2.FeatureFlags
    polling_time: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., name: _Optional[str] = ..., category: _Optional[str] = ..., display_name: _Optional[str] = ..., sfnc_namespace: _Optional[str] = ..., unit: _Optional[str] = ..., data_type: _Optional[int] = ..., flags: _Optional[_Union[_feature_flags_pb2.FeatureFlags, _Mapping]] = ..., polling_time: _Optional[int] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ItineraryErase(_message.Message):
    __slots__ = ("participant", "routes", "itinerary_version")
    PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    ROUTES_FIELD_NUMBER: _ClassVar[int]
    ITINERARY_VERSION_FIELD_NUMBER: _ClassVar[int]
    participant: int
    routes: _containers.RepeatedScalarFieldContainer[int]
    itinerary_version: int
    def __init__(self, participant: _Optional[int] = ..., routes: _Optional[_Iterable[int]] = ..., itinerary_version: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.qb_device_msgs.msg import resource_data_pb2 as _resource_data_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class State(_message.Message):
    __slots__ = ("header", "actuators", "joints", "is_reliable", "consecutive_failures")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ACTUATORS_FIELD_NUMBER: _ClassVar[int]
    JOINTS_FIELD_NUMBER: _ClassVar[int]
    IS_RELIABLE_FIELD_NUMBER: _ClassVar[int]
    CONSECUTIVE_FAILURES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    actuators: _containers.RepeatedCompositeFieldContainer[_resource_data_pb2.ResourceData]
    joints: _containers.RepeatedCompositeFieldContainer[_resource_data_pb2.ResourceData]
    is_reliable: bool
    consecutive_failures: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., actuators: _Optional[_Iterable[_Union[_resource_data_pb2.ResourceData, _Mapping]]] = ..., joints: _Optional[_Iterable[_Union[_resource_data_pb2.ResourceData, _Mapping]]] = ..., is_reliable: bool = ..., consecutive_failures: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DqnRequest(_message.Message):
    __slots__ = ("header", "action", "init")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ACTION_FIELD_NUMBER: _ClassVar[int]
    INIT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    action: int
    init: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., action: _Optional[int] = ..., init: bool = ...) -> None: ...

class DqnResponse(_message.Message):
    __slots__ = ("header", "state", "reward", "done")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    REWARD_FIELD_NUMBER: _ClassVar[int]
    DONE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    state: _containers.RepeatedScalarFieldContainer[float]
    reward: float
    done: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., state: _Optional[_Iterable[float]] = ..., reward: _Optional[float] = ..., done: bool = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class IntrusionDatum(_message.Message):
    __slots__ = ("header", "size", "flags")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    FLAGS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    size: int
    flags: _containers.RepeatedScalarFieldContainer[bool]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., size: _Optional[int] = ..., flags: _Optional[_Iterable[bool]] = ...) -> None: ...



from make87_messages_ros2.jazzy.moveit_msgs.msg import cartesian_trajectory_pb2 as _cartesian_trajectory_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from make87_messages_ros2.jazzy.trajectory_msgs.msg import joint_trajectory_pb2 as _joint_trajectory_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenericTrajectory(_message.Message):
    __slots__ = ("header", "joint_trajectory", "cartesian_trajectory")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    JOINT_TRAJECTORY_FIELD_NUMBER: _ClassVar[int]
    CARTESIAN_TRAJECTORY_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    joint_trajectory: _containers.RepeatedCompositeFieldContainer[_joint_trajectory_pb2.JointTrajectory]
    cartesian_trajectory: _containers.RepeatedCompositeFieldContainer[_cartesian_trajectory_pb2.CartesianTrajectory]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., joint_trajectory: _Optional[_Iterable[_Union[_joint_trajectory_pb2.JointTrajectory, _Mapping]]] = ..., cartesian_trajectory: _Optional[_Iterable[_Union[_cartesian_trajectory_pb2.CartesianTrajectory, _Mapping]]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.soccer_object_msgs.msg import flag_pb2 as _flag_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FlagArray(_message.Message):
    __slots__ = ("header", "flags")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    FLAGS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    flags: _containers.RepeatedCompositeFieldContainer[_flag_pb2.Flag]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., flags: _Optional[_Iterable[_Union[_flag_pb2.Flag, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/map_msgs/msg/projected_map.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.nav_msgs.msg import occupancy_grid_pb2 as make87__messages__ros2_dot_rolling_dot_nav__msgs_dot_msg_dot_occupancy__grid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/rolling/map_msgs/msg/projected_map.proto\x12)make87_messages_ros2.rolling.map_msgs.msg\x1a>make87_messages_ros2/rolling/nav_msgs/msg/occupancy_grid.proto\"s\n\x0cProjectedMap\x12\x45\n\x03map\x18\x01 \x01(\x0b\x32\x38.make87_messages_ros2.rolling.nav_msgs.msg.OccupancyGrid\x12\r\n\x05min_z\x18\x02 \x01(\x01\x12\r\n\x05max_z\x18\x03 \x01(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.map_msgs.msg.projected_map_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_PROJECTEDMAP']._serialized_start=172
  _globals['_PROJECTEDMAP']._serialized_end=287
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as _time_pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as _pose_pb2
from make87_messages_ros2.rolling.rc_common_msgs.msg import return_code_pb2 as _return_code_pb2
from make87_messages_ros2.rolling.rc_reason_msgs.msg import collision_detection_pb2 as _collision_detection_pb2
from make87_messages_ros2.rolling.rc_reason_msgs.msg import grasp_pb2 as _grasp_pb2
from make87_messages_ros2.rolling.rc_reason_msgs.msg import load_carrier_pb2 as _load_carrier_pb2
from make87_messages_ros2.rolling.rc_reason_msgs.msg import match_pb2 as _match_pb2
from make87_messages_ros2.rolling.rc_reason_msgs.msg import silhouette_match_object_pb2 as _silhouette_match_object_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SilhouetteMatchDetectObjectRequest(_message.Message):
    __slots__ = ("object_to_detect", "offset", "pose_frame", "robot_pose", "load_carrier_id", "collision_detection", "object_plane_detection")
    OBJECT_TO_DETECT_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    POSE_FRAME_FIELD_NUMBER: _ClassVar[int]
    ROBOT_POSE_FIELD_NUMBER: _ClassVar[int]
    LOAD_CARRIER_ID_FIELD_NUMBER: _ClassVar[int]
    COLLISION_DETECTION_FIELD_NUMBER: _ClassVar[int]
    OBJECT_PLANE_DETECTION_FIELD_NUMBER: _ClassVar[int]
    object_to_detect: _silhouette_match_object_pb2.SilhouetteMatchObject
    offset: float
    pose_frame: str
    robot_pose: _pose_pb2.Pose
    load_carrier_id: str
    collision_detection: _collision_detection_pb2.CollisionDetection
    object_plane_detection: bool
    def __init__(self, object_to_detect: _Optional[_Union[_silhouette_match_object_pb2.SilhouetteMatchObject, _Mapping]] = ..., offset: _Optional[float] = ..., pose_frame: _Optional[str] = ..., robot_pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., load_carrier_id: _Optional[str] = ..., collision_detection: _Optional[_Union[_collision_detection_pb2.CollisionDetection, _Mapping]] = ..., object_plane_detection: bool = ...) -> None: ...

class SilhouetteMatchDetectObjectResponse(_message.Message):
    __slots__ = ("timestamp", "object_id", "matches", "grasps", "load_carriers", "return_code")
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
    MATCHES_FIELD_NUMBER: _ClassVar[int]
    GRASPS_FIELD_NUMBER: _ClassVar[int]
    LOAD_CARRIERS_FIELD_NUMBER: _ClassVar[int]
    RETURN_CODE_FIELD_NUMBER: _ClassVar[int]
    timestamp: _time_pb2.Time
    object_id: str
    matches: _containers.RepeatedCompositeFieldContainer[_match_pb2.Match]
    grasps: _containers.RepeatedCompositeFieldContainer[_grasp_pb2.Grasp]
    load_carriers: _containers.RepeatedCompositeFieldContainer[_load_carrier_pb2.LoadCarrier]
    return_code: _return_code_pb2.ReturnCode
    def __init__(self, timestamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., object_id: _Optional[str] = ..., matches: _Optional[_Iterable[_Union[_match_pb2.Match, _Mapping]]] = ..., grasps: _Optional[_Iterable[_Union[_grasp_pb2.Grasp, _Mapping]]] = ..., load_carriers: _Optional[_Iterable[_Union[_load_carrier_pb2.LoadCarrier, _Mapping]]] = ..., return_code: _Optional[_Union[_return_code_pb2.ReturnCode, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/lgsvl_msgs/msg/detection3_d_array.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.lgsvl_msgs.msg import detection3_d_pb2 as make87__messages__ros2_dot_jazzy_dot_lgsvl__msgs_dot_msg_dot_detection3__d__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/jazzy/lgsvl_msgs/msg/detection3_d_array.proto\x12)make87_messages_ros2.jazzy.lgsvl_msgs.msg\x1a<make87_messages_ros2/jazzy/lgsvl_msgs/msg/detection3_d.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\x9f\x01\n\x10\x44\x65tection3DArray\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12J\n\ndetections\x18\x02 \x03(\x0b\x32\x36.make87_messages_ros2.jazzy.lgsvl_msgs.msg.Detection3Db\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.lgsvl_msgs.msg.detection3_d_array_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DETECTION3DARRAY']._serialized_start=230
  _globals['_DETECTION3DARRAY']._serialized_end=389
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.vimbax_camera_msgs.msg import error_pb2 as _error_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SettingsLoadSaveRequest(_message.Message):
    __slots__ = ("header", "filename")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    FILENAME_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    filename: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., filename: _Optional[str] = ...) -> None: ...

class SettingsLoadSaveResponse(_message.Message):
    __slots__ = ("header", "error")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    error: _error_pb2.Error
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., error: _Optional[_Union[_error_pb2.Error, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_traffic_msgs/msg/route.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import traffic_dependency_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__traffic__msgs_dot_msg_dot_traffic__dependency__pb2
from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import trajectory_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__traffic__msgs_dot_msg_dot_trajectory__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/rolling/rmf_traffic_msgs/msg/route.proto\x12\x31make87_messages_ros2.rolling.rmf_traffic_msgs.msg\x1aJmake87_messages_ros2/rolling/rmf_traffic_msgs/msg/traffic_dependency.proto\x1a\x42make87_messages_ros2/rolling/rmf_traffic_msgs/msg/trajectory.proto\"\xd8\x01\n\x05Route\x12\x0b\n\x03map\x18\x01 \x01(\t\x12Q\n\ntrajectory\x18\x02 \x01(\x0b\x32=.make87_messages_ros2.rolling.rmf_traffic_msgs.msg.Trajectory\x12\x13\n\x0b\x63heckpoints\x18\x03 \x03(\x04\x12Z\n\x0c\x64\x65pendencies\x18\x04 \x03(\x0b\x32\x44.make87_messages_ros2.rolling.rmf_traffic_msgs.msg.TrafficDependencyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_traffic_msgs.msg.route_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ROUTE']._serialized_start=261
  _globals['_ROUTE']._serialized_end=477
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class JointStiffnesses(_message.Message):
    __slots__ = ("indexes", "stiffnesses")
    INDEXES_FIELD_NUMBER: _ClassVar[int]
    STIFFNESSES_FIELD_NUMBER: _ClassVar[int]
    indexes: _containers.RepeatedScalarFieldContainer[int]
    stiffnesses: _containers.RepeatedScalarFieldContainer[float]
    def __init__(self, indexes: _Optional[_Iterable[int]] = ..., stiffnesses: _Optional[_Iterable[float]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class MoveItErrorCodes(_message.Message):
    __slots__ = ("val", "message", "source")
    VAL_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    val: int
    message: str
    source: str
    def __init__(self, val: _Optional[int] = ..., message: _Optional[str] = ..., source: _Optional[str] = ...) -> None: ...



from make87_messages_ros2.jazzy.builtin_interfaces.msg import duration_pb2 as _duration_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class JointTrajectoryPoint(_message.Message):
    __slots__ = ("positions", "velocities", "accelerations", "effort", "time_from_start")
    POSITIONS_FIELD_NUMBER: _ClassVar[int]
    VELOCITIES_FIELD_NUMBER: _ClassVar[int]
    ACCELERATIONS_FIELD_NUMBER: _ClassVar[int]
    EFFORT_FIELD_NUMBER: _ClassVar[int]
    TIME_FROM_START_FIELD_NUMBER: _ClassVar[int]
    positions: _containers.RepeatedScalarFieldContainer[float]
    velocities: _containers.RepeatedScalarFieldContainer[float]
    accelerations: _containers.RepeatedScalarFieldContainer[float]
    effort: _containers.RepeatedScalarFieldContainer[float]
    time_from_start: _duration_pb2.Duration
    def __init__(self, positions: _Optional[_Iterable[float]] = ..., velocities: _Optional[_Iterable[float]] = ..., accelerations: _Optional[_Iterable[float]] = ..., effort: _Optional[_Iterable[float]] = ..., time_from_start: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/marine_acoustic_msgs/msg/dvl.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import vector3_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_vector3__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/rolling/marine_acoustic_msgs/msg/dvl.proto\x12\x35make87_messages_ros2.rolling.marine_acoustic_msgs.msg\x1a<make87_messages_ros2/rolling/geometry_msgs/msg/vector3.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xb2\x04\n\x03\x44vl\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x15\n\rvelocity_mode\x18\x02 \x01(\r\x12\x10\n\x08\x64vl_type\x18\x03 \x01(\r\x12I\n\x08velocity\x18\x04 \x01(\x0b\x32\x37.make87_messages_ros2.rolling.geometry_msgs.msg.Vector3\x12\x16\n\x0evelocity_covar\x18\x05 \x03(\x01\x12\x10\n\x08\x61ltitude\x18\x06 \x01(\x01\x12\x12\n\ncourse_gnd\x18\x07 \x01(\x01\x12\x11\n\tspeed_gnd\x18\x08 \x01(\x01\x12\x16\n\x0enum_good_beams\x18\t \x01(\r\x12\x13\n\x0bsound_speed\x18\n \x01(\x02\x12\x19\n\x11\x62\x65\x61m_ranges_valid\x18\x0b \x01(\x08\x12\x1d\n\x15\x62\x65\x61m_velocities_valid\x18\x0c \x01(\x08\x12N\n\rbeam_unit_vec\x18\r \x03(\x0b\x32\x37.make87_messages_ros2.rolling.geometry_msgs.msg.Vector3\x12\r\n\x05range\x18\x0e \x03(\x01\x12\x13\n\x0brange_covar\x18\x0f \x03(\x02\x12\x14\n\x0c\x62\x65\x61m_quality\x18\x10 \x03(\x02\x12\x15\n\rbeam_velocity\x18\x11 \x03(\x02\x12\x1b\n\x13\x62\x65\x61m_velocity_covar\x18\x12 \x03(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.marine_acoustic_msgs.msg.dvl_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DVL']._serialized_start=241
  _globals['_DVL']._serialized_end=803
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.soccer_vision_3d_msgs.msg import marking_ellipse_pb2 as _marking_ellipse_pb2
from make87_messages_ros2.jazzy.soccer_vision_3d_msgs.msg import marking_intersection_pb2 as _marking_intersection_pb2
from make87_messages_ros2.jazzy.soccer_vision_3d_msgs.msg import marking_segment_pb2 as _marking_segment_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MarkingArray(_message.Message):
    __slots__ = ("header", "ellipses", "intersections", "segments")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ELLIPSES_FIELD_NUMBER: _ClassVar[int]
    INTERSECTIONS_FIELD_NUMBER: _ClassVar[int]
    SEGMENTS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ellipses: _containers.RepeatedCompositeFieldContainer[_marking_ellipse_pb2.MarkingEllipse]
    intersections: _containers.RepeatedCompositeFieldContainer[_marking_intersection_pb2.MarkingIntersection]
    segments: _containers.RepeatedCompositeFieldContainer[_marking_segment_pb2.MarkingSegment]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ellipses: _Optional[_Iterable[_Union[_marking_ellipse_pb2.MarkingEllipse, _Mapping]]] = ..., intersections: _Optional[_Iterable[_Union[_marking_intersection_pb2.MarkingIntersection, _Mapping]]] = ..., segments: _Optional[_Iterable[_Union[_marking_segment_pb2.MarkingSegment, _Mapping]]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.psdk_interfaces.msg import hms_info_msg_pb2 as _hms_info_msg_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class HmsInfoTable(_message.Message):
    __slots__ = ("header", "num_msg", "table")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    NUM_MSG_FIELD_NUMBER: _ClassVar[int]
    TABLE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    num_msg: int
    table: _containers.RepeatedCompositeFieldContainer[_hms_info_msg_pb2.HmsInfoMsg]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., num_msg: _Optional[int] = ..., table: _Optional[_Iterable[_Union[_hms_info_msg_pb2.HmsInfoMsg, _Mapping]]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.off_highway_premium_radar_sample_msgs.msg import operation_mode_pb2 as _operation_mode_pb2
from make87_messages_ros2.humble.off_highway_premium_radar_sample_msgs.msg import time_pb2 as _time_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LocationAttributesHeader(_message.Message):
    __slots__ = ("header", "lgp_version", "block_counter", "start_measurement", "operation_mode", "data_measured")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    LGP_VERSION_FIELD_NUMBER: _ClassVar[int]
    BLOCK_COUNTER_FIELD_NUMBER: _ClassVar[int]
    START_MEASUREMENT_FIELD_NUMBER: _ClassVar[int]
    OPERATION_MODE_FIELD_NUMBER: _ClassVar[int]
    DATA_MEASURED_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    lgp_version: int
    block_counter: int
    start_measurement: _time_pb2.Time
    operation_mode: _operation_mode_pb2.OperationMode
    data_measured: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., lgp_version: _Optional[int] = ..., block_counter: _Optional[int] = ..., start_measurement: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., operation_mode: _Optional[_Union[_operation_mode_pb2.OperationMode, _Mapping]] = ..., data_measured: bool = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class NavPVT(_message.Message):
    __slots__ = ("i_tow", "year", "month", "day", "hour", "min", "sec", "valid", "t_acc", "nano", "fix_type", "flags", "flags2", "num_sv", "lon", "lat", "height", "h_msl", "h_acc", "v_acc", "vel_n", "vel_e", "vel_d", "g_speed", "heading", "s_acc", "head_acc", "p_dop", "reserved1", "head_veh", "mag_dec", "mag_acc")
    I_TOW_FIELD_NUMBER: _ClassVar[int]
    YEAR_FIELD_NUMBER: _ClassVar[int]
    MONTH_FIELD_NUMBER: _ClassVar[int]
    DAY_FIELD_NUMBER: _ClassVar[int]
    HOUR_FIELD_NUMBER: _ClassVar[int]
    MIN_FIELD_NUMBER: _ClassVar[int]
    SEC_FIELD_NUMBER: _ClassVar[int]
    VALID_FIELD_NUMBER: _ClassVar[int]
    T_ACC_FIELD_NUMBER: _ClassVar[int]
    NANO_FIELD_NUMBER: _ClassVar[int]
    FIX_TYPE_FIELD_NUMBER: _ClassVar[int]
    FLAGS_FIELD_NUMBER: _ClassVar[int]
    FLAGS2_FIELD_NUMBER: _ClassVar[int]
    NUM_SV_FIELD_NUMBER: _ClassVar[int]
    LON_FIELD_NUMBER: _ClassVar[int]
    LAT_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    H_MSL_FIELD_NUMBER: _ClassVar[int]
    H_ACC_FIELD_NUMBER: _ClassVar[int]
    V_ACC_FIELD_NUMBER: _ClassVar[int]
    VEL_N_FIELD_NUMBER: _ClassVar[int]
    VEL_E_FIELD_NUMBER: _ClassVar[int]
    VEL_D_FIELD_NUMBER: _ClassVar[int]
    G_SPEED_FIELD_NUMBER: _ClassVar[int]
    HEADING_FIELD_NUMBER: _ClassVar[int]
    S_ACC_FIELD_NUMBER: _ClassVar[int]
    HEAD_ACC_FIELD_NUMBER: _ClassVar[int]
    P_DOP_FIELD_NUMBER: _ClassVar[int]
    RESERVED1_FIELD_NUMBER: _ClassVar[int]
    HEAD_VEH_FIELD_NUMBER: _ClassVar[int]
    MAG_DEC_FIELD_NUMBER: _ClassVar[int]
    MAG_ACC_FIELD_NUMBER: _ClassVar[int]
    i_tow: int
    year: int
    month: int
    day: int
    hour: int
    min: int
    sec: int
    valid: int
    t_acc: int
    nano: int
    fix_type: int
    flags: int
    flags2: int
    num_sv: int
    lon: int
    lat: int
    height: int
    h_msl: int
    h_acc: int
    v_acc: int
    vel_n: int
    vel_e: int
    vel_d: int
    g_speed: int
    heading: int
    s_acc: int
    head_acc: int
    p_dop: int
    reserved1: _containers.RepeatedScalarFieldContainer[int]
    head_veh: int
    mag_dec: int
    mag_acc: int
    def __init__(self, i_tow: _Optional[int] = ..., year: _Optional[int] = ..., month: _Optional[int] = ..., day: _Optional[int] = ..., hour: _Optional[int] = ..., min: _Optional[int] = ..., sec: _Optional[int] = ..., valid: _Optional[int] = ..., t_acc: _Optional[int] = ..., nano: _Optional[int] = ..., fix_type: _Optional[int] = ..., flags: _Optional[int] = ..., flags2: _Optional[int] = ..., num_sv: _Optional[int] = ..., lon: _Optional[int] = ..., lat: _Optional[int] = ..., height: _Optional[int] = ..., h_msl: _Optional[int] = ..., h_acc: _Optional[int] = ..., v_acc: _Optional[int] = ..., vel_n: _Optional[int] = ..., vel_e: _Optional[int] = ..., vel_d: _Optional[int] = ..., g_speed: _Optional[int] = ..., heading: _Optional[int] = ..., s_acc: _Optional[int] = ..., head_acc: _Optional[int] = ..., p_dop: _Optional[int] = ..., reserved1: _Optional[_Iterable[int]] = ..., head_veh: _Optional[int] = ..., mag_dec: _Optional[int] = ..., mag_acc: _Optional[int] = ...) -> None: ...
